# README

## Requirements

- APEX must be installed in the database and a *workspace* created.
- Either DBA supplies the password for the oracle user `ORDS_PUBLIC_USER` or the respective Atlas secret must be created by someone else.


## Install ORDS in database

ORDS is usually installed in the database already by a DBA or an automatic routine.


## Oracle REST Data Services (ORDS) in Atlas

ORDS will run as standalone in a generic image with its own JDK bundled

In the examples below:
- replace it-solution `dbtool` with your it-solution.
- use correct service for database
- use correct hostname for `ORDS_EXTERNAL_HOST`
- `ATLAS_DB_USERNAME` is oracle user for APEX-applications (i.e. where APEX applications will be installed).

### Create artifact

Use script `create_artifact.sh` to build and upload the artifact to artrepo.vegvesen.no. The script will ask for username and password if the environment variables  `repo_user` and `repo_password` are not defined.


Change variables as needed:

- `WORKDIR` to a temporary directory for downloaded files and other ephemeral stuff.
- `TARFILE` name of uploaded artifact file
- `REPO_URL` URL to Artifact repository file.

### Atlas default IT-løsning

Sett riktig default, eksempelvis:

    ac config set-iktlosning dbtool

### Atlas build

Example:

    ac build oracle-rest -U https://artrepo.vegvesen.no/artifactory/generic-local-snapshots/ikt/meridian/ords/oracle_rest.tar.gz -b generic -v 1.0.0 --block-until-finished

Make sure the version used here corresponds to the tag in the deployment description, see `atlas/ords-okular.json`.

### Create Application Environment


List existing environments:

    ac get environment

An environment can be created with:

    ac create environment stm-1 -i dbtool -r stm

### Initialize and configure deploy

Initialize deploy:

    mkdir -p atlas
    cd atlas
    ac init config --iktlosning dbtool

Add environment with:

    ac init environment stm-1

List existing images (built earlier with `ac build ...`:

    ac get image -o wide

Add deployment description:

    ac init deploy oracle-rest --image-name atlas-docker.artrepo.vegvesen.no/meridian/oracle-rest --image-tag 1.0.0

The parameter values in command above must correspond to the listing from `ac get image -o wide`.

Add environment variables:

These are common for all environments (usually only need to change the name of your APEX workspace, and if you are not using APEX you can skip it):

    ac init envvar APEX_WORKSPACE --value OKULAR -d ords-okular
    ac init envvar ATLAS_MAIN_ENTRYPOINT --value start.sh -d ords-okular
    ac init envvar JDBC_INITIAL_LIMIT --value 10 -d ords-okular
    ac init envvar JDBC_MAX_LIMIT --value 30 -d ords-okular
    ac init envvar ORACLE_PORT --value 1521 -d ords-okular


These are specific for each environment:

    ac init envvar ATLAS_DB_URL --value "jdbc:oracle:thin:@svvuexacc-scan:1521/dbtool_stm.vegvesen.no" -e stm-1 -d ords-okular
    ac init envvar ATLAS_DB_USERNAME --value dbtool -e stm-1 -d ords-okular
    ac init envvar ORACLE_HOST --value svvuexacc-scan.vegvesen.no -e stm-1 -d ords-okular
    ac init envvar ORACLE_SERVICE --value dbtool_stm.vegvesen.no -e stm-1 -d ords-okular
    ac init envvar ORDS_EXTERNAL_HOST --value dbtool.utv.atlas.vegvesen.no -e stm-1 -d ords-okular

### Add vault and add secrets

Each environment needs a vault. Example for stm:

    ac init vault -d ords-okular -e stm-1

This needs to be in place in order to add secrets to the environment.

    ac init secret ATLAS_DB_PASSWORD -d ords-okular -e stm-1 --type env
    ac init secret ORACLE_DB_PASSWORD -d ords-okular -e stm-1 --type env

`ATLAS_DB_PASSWORD` is for database user that will host the APEX applications or where the REST API will be deployed. `ORACLE_DB_PASSWORD` is passord for `ORDS_PUBLIC_USER` supplied by DBA or found in PAM. 


### Add services

List services:

    ac get service

Add openid and oracledb:

    ac init serviceinstance openid
    ac init serviceinstance oracledb

This will open a web browser with a form to fill in and when completed will create a file called `services.json`. See comments below regarding redirectURIs.

    ac create serviceinstance apex-openid -e stm-1
    ac create serviceinstance oracle-db -e stm-1


### Add resources

    ac init resource cpu -d oracle-rest --min 100m -e stm-1
    ac init resource memory -d oracle-rest --min 300M --max 1500M -e stm-1

### Add probes

    ac init probe readiness  --context-path /index.html -d ords-okular -e stm-1 
    ac init probe liveness --context-path /index.html -d  ords-okular  -e stm-1
    ac init probe startup --context-path /index.html  -d ords-okular -e stm-1

Add lines for `failureThreshold` and `periodSeconds` to `stm-1/ords-okular.json` for `spec` of startup probe: 

```
"startup": {
        "type": "HttpProbe",
        "spec": {
          "failureThreshold": 9,
          "path": "/index.html",
          "periodSeconds": 30
        }
```



### Add routes

Add route:

    ac init route -d ords-okular -e stm-1 --expose internal --hostname ords-okular.utv.atlas.vegvesen.no \
	--termination passthrough

### Deploy image

Create deploy:

    ac create deploy ords-okular -e stm-1

To delete a running deploy:

    ac delete deploy ords-okular -e stm-1






### redirectUris i OpenID

Assuming the context root for ORDS is `/ords`, which is default, APEX will always use the relative URI `/ords/apex_authentication.callback` as redirect URI after successful authentiation. Atlas also included port 80 in the redirect URI. Example of correct configuration:

   "redirectUris": [
            "https://ords-okular.atlas.vegvesen.no/ords/apex_authentication.callback",
            "https://ords-okular.test.atlas.vegvesen.no/ords/apex_authentication.callback",
            "https://ords-okular.utv.atlas.vegvesen.no/ords/apex_authentication.callback"
          ],

