#!/bin/bash -e


JDK_FILE=jdk-21_linux-x64_bin.tar.gz

JAVA_HOME=$PWD/jdk-21.0.3
_JAVA_OPTIONS="-Xms512m -Xmx1g"


PATH=${JAVA_HOME}/bin:$PATH
export JAVA_HOME PATH _JAVA_OPTIONS

if [  -z "$ORACLE_HOST"  -o  -z "$ORACLE_PORT"  -o  -z "$ORACLE_SERVICE"  -o  -z "$ORACLE_DB_PASSWORD" -o -z "$ORDS_EXTERNAL_HOST" ] ; then
	echo "Check environment. One of ORACLE_HOST, ORACLE_PORT, ORACLE_SERVICE, ORACLE_DB_PASSWORD, or ORDS_EXTERNAL_HOST not defined. Aborting"
	exit 1
fi

if [ -r provisioning_done ] ; then
	echo Provisioning already done, starting ORDS
	bin/ords --config ordsconfig serve #runs until killed
	exit
fi

echo Starting provisioning
if [ ! -r $JDK_FILE ] ; then
   echo $JDK_FILE does not exist or is not readable
   exit 1
fi

echo Unpacking JDK
tar xzf $JDK_FILE


echo Update configuration from environment



ORDS=$PWD/bin/ords

$ORDS --config ordsconfig config set db.customURL "$ATLAS_DB_URL"
$ORDS --config ordsconfig config set db.connectionType customurl
echo ${ORACLE_DB_PASSWORD} | $ORDS --config ordsconfig config secret --password-stdin db.password
if [ -n "$APEX_IMAGE_PATH" ] ; then
   $ORDS --config ordsconfig config set standalone.static.context.path $APEX_IMAGE_PATH
fi
$ORDS --config ordsconfig config set standalone.static.path $PWD/images
$ORDS --config ordsconfig config set jdbc.InitialLimit ${JDBC_INITIAL_LIMIT:-3}
$ORDS --config ordsconfig config set jdbc.MaxLimit ${JDBC_MAX_LIMIT:-20}
$ORDS --config ordsconfig config set standalone.http.port 8080
$ORDS --config ordsconfig config set security.verifySSL False
$ORDS --config ordsconfig config set security.externalSessionTrustedOrigins "https://${ORDS_EXTERNAL_HOST},http://${ORDS_EXTERNAL_HOST}"
$ORDS --config ordsconfig config set feature.sdw true
$ORDS --config ordsconfig config set mongo.enabled true
$ORDS --config ordsconfig config set --global instance.api.enabled true


if [ -r ApexCredential.jar -a -n "$APEX_WORKSPACE" ] ; then
	echo Update APEX credential in database for workspace $APEX_WORKSPACE
	java -jar ApexCredential.jar
fi

echo Provisioning done
touch provisioning_done

echo Starting ORDS
JAVA_TOOL_OPTIONS="-Doracle.ml.version_check=false"
export JAVA_TOOL_OPTIONS
$ORDS --config ordsconfig serve 


